# Copyright © 2024 Yannick Gingras <ygingras@ygingras.net> and contributors

# This file is part of Minute Maze.

# Minute Maze is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# Minute Maze is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Minute Maze.  If not, see <https://www.gnu.org/licenses/>.

## A tile highlight that draws itself with primitives rather than a sprite.
class_name DynHighlight extends Node2D

@export var on_screen_secs:float
@export var alpha = 0.16

func _ready() -> void:
	modulate.a = 0.0
	var anim = create_tween()
	anim.tween_property(self, "modulate:a", 1.0, 0.2)
	if on_screen_secs:
		var fade_timer = get_tree().create_timer(on_screen_secs)
		fade_timer.timeout.connect(fadeout)

func _draw() -> void:
	var rect = Rect2(-16, -16, 32, 32)
	var col = modulate
	col.a = alpha
	draw_rect(rect, col)

	col.a = alpha * 0.7
	var k = 4
	for i in k:
		var size = Vector2.ONE * (32 - k + i)
		rect = Rect2(-size / 2.0, size)
		draw_rect(rect, col, false, k - i)

func fadeout():
	var anim = create_tween()
	anim.tween_property(self, "modulate:a", 0.0, 0.5)
